@@ -42,9 +42,12 @@ class OktaAuthConfig():
         elif self._value.has_option('default', 'app-link'):
             app_link = self._value.get('default', 'app-link')
 
-        if not validators.url(app_link):
-            self.logger.error("The app-link provided: %s is an invalid url" % app_link)
-            exit(-1)
+        try:
+            if not validators.url(app_link):
+                self.logger.error("The app-link provided: %s is an invalid url" % app_link)
+                sys.exit(-1)
+        except TypeError as ex:
+            self.logger.error("Malformed string in app link URL. Ensure there are no invalid characters.")
 
         self.logger.info("App Link set as: %s" % app_link)
         return app_link
