@@ -11,11 +11,14 @@ from oktaawscli.okta_auth_config import OktaAuthConfig
 from oktaawscli.aws_auth import AwsAuth
 
 def get_credentials(aws_auth, okta_profile, profile,
-                    verbose, logger, totp_token, cache, refresh_role):
+                    verbose, logger, totp_token, cache, refresh_role, 
+                    okta_username=None, okta_password=None):
     """ Gets credentials from Okta """
 
     okta_auth_config = OktaAuthConfig(logger)
-    okta = OktaAuth(okta_profile, verbose, logger, totp_token, okta_auth_config)
+    okta = OktaAuth(okta_profile, verbose, logger, totp_token, 
+        okta_auth_config, okta_username, okta_password)
+
 
     _, assertion = okta.get_assertion()
     role = aws_auth.choose_aws_role(assertion, refresh_role)
@@ -72,18 +75,22 @@ def console_output(access_key_id, secret_access_key, session_token, verbose):
 @click.option('-d', '--debug', is_flag=True, help='Enables debug mode')
 @click.option('-f', '--force', is_flag=True, help='Forces new STS credentials. \
 Skips STS credentials validation.')
-@click.option('--okta-profile', help="Name of the profile to use in .okta-aws. \
+@click.option('-o', '--okta-profile', help="Name of the profile to use in .okta-aws. \
 If none is provided, then the default profile will be used.\n")
-@click.option('--profile', help="Name of the profile to store temporary \
+@click.option('-p', '--profile', help="Name of the profile to store temporary \
 credentials in ~/.aws/credentials. If profile doesn't exist, it will be \
 created. If omitted, credentials will output to console.\n")
 @click.option('-c', '--cache', is_flag=True, help='Cache the default profile credentials \
 to ~/.okta-credentials.cache\n')
+@click.option('-r', '--refresh-role', is_flag=True, help='Refreshes the AWS role to be assumed')
 @click.option('-t', '--token', help='TOTP token from your authenticator app')
 @click.option('-l', '--lookup', is_flag=True, help='Look up AWS account names')
+@click.option('-U', '--username', 'okta_username', help="Okta username")
+@click.option('-P', '--password', 'okta_password', help="Okta password")
 @click.argument('awscli_args', nargs=-1, type=click.UNPROCESSED)
 def main(okta_profile, profile, verbose, version,
-         debug, force, cache, lookup, awscli_args, token):
+         debug, force, cache, lookup, awscli_args,
+         refresh_role, token, okta_username, okta_password):
     """ Authenticate to awscli using Okta """
     if version:
         print(__version__)
@@ -110,9 +117,8 @@ def main(okta_profile, profile, verbose, version,
 
             logger.info("Force option selected, \
                 getting new credentials anyway.")
-        refresh_role = True if force else False
         get_credentials(
-            aws_auth, okta_profile, profile, verbose, logger, token, cache, refresh_role
+            aws_auth, okta_profile, profile, verbose, logger, token, cache, refresh_role, okta_username, okta_password
         )
 
     if awscli_args:
